package com.example.greenwatch.viewmodels;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.view.SurfaceHolder;

import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.example.greenwatch.alarmrecorder.AlarmRecorder;
import com.example.greenwatch.communication.WiFiCommunication;
import com.example.greenwatch.models.Device;
import com.example.greenwatch.repositories.DeviceRepository;

import java.util.List;

public class MainActivityViewModel extends ViewModel implements ViewModelInterface {

    private MutableLiveData<List<Device>> mDeviceList;
    private MutableLiveData<List<Device>> mAlarmHistoryList;
    private MutableLiveData<Boolean> mStartAlarmRecording;
    private DeviceRepository mDeviceRepository;
    private AlarmRecorder mAlarmRecorder;
    private static final int RIGHTS_REQUEST_CAMERA = 10;
    private static final int REQUEST_PERMISSION = 200;

    @Override
    public void init(SurfaceHolder previewHolder) {
        WiFiCommunication mWiFiCommunication;
        if(mDeviceList != null) {
            return;
        }
        if (mAlarmRecorder == null) {
            mAlarmRecorder = AlarmRecorder.getInstance();
        }
        //todo: check if WiFi instanz can be hold only by the repository
        mDeviceRepository = DeviceRepository.getInstance();
        mWiFiCommunication = WiFiCommunication.getInstance();
        mDeviceRepository.setWiFiCommunication(mWiFiCommunication);
        mWiFiCommunication.setDeviceRepository(mDeviceRepository);
        //mDeviceRepository.createNewDevice(mDeviceRepository.getSystemTimeStamp(), mDeviceRepository.getLocalDeviceUUID(), false, "No Sensor selected", 0);
        mDeviceList = mDeviceRepository.getConnectedDeviceList();
        mAlarmHistoryList = mDeviceRepository.getAlarmHistoryDeviceList();
        mStartAlarmRecording = mDeviceRepository.getStartAlarmRecording();
        setAlarmRecordingPreviewHolder(previewHolder);
    }

    public boolean isCameraAccessAllowed(Context context) {
        return ContextCompat.checkSelfPermission(context, android.Manifest.permission.CAMERA) == PackageManager.PERMISSION_GRANTED;
    }

    public void accessRequestCamera(Activity activity) {
        ActivityCompat.requestPermissions(activity, new String[]{android.Manifest.permission.CAMERA}, RIGHTS_REQUEST_CAMERA);
    }

    public boolean isAudioRecordingAccessAllowed(Context context) {
        return ContextCompat.checkSelfPermission(context, Manifest.permission.RECORD_AUDIO) == PackageManager.PERMISSION_GRANTED;
    }

    public void accessRequestAudioRecording(Activity activity) {
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.RECORD_AUDIO}, REQUEST_PERMISSION);
    }

    public boolean isWriteExternalStorageAccessAllowed(Context context) {
        return ContextCompat.checkSelfPermission(context, Manifest.permission.WRITE_EXTERNAL_STORAGE) == PackageManager.PERMISSION_GRANTED;
    }

    public void accessRequestWriteExternalStorage(Activity activity) {
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.WRITE_EXTERNAL_STORAGE}, REQUEST_PERMISSION);
    }

    @Override
    public LiveData<List<Device>> getConnectedDeviceList() {
        return mDeviceList;
    }

    @Override
    public LiveData<List<Device>> getAlarmHistoryList() {
        return mAlarmHistoryList;
    }

    @Override
    public LiveData<Boolean> getStartAlarmRecording() {
        return mStartAlarmRecording;
    }

    @Override
    public void updateDevice(String deviceID, String timeStamp, boolean sensorStatus, String sensorType, int sensorMassage) {
        mDeviceRepository.updateDevice(deviceID, timeStamp, sensorStatus, sensorType, sensorMassage);
    }

    @Override
    public void setTimeStamp(String deviceID, String timeStamp) {
        mDeviceRepository.setTimeStamp(deviceID, timeStamp);
    }

    @Override
    public String getTimeStamp(String deviceID) {
        return mDeviceRepository.getTimeStamp(deviceID);
    }

    @Override
    public void setDeviceID(String deviceID, String newDeviceID) {
        mDeviceRepository.setDeviceID(deviceID, newDeviceID);
    }

    @Override
    public String getDeviceID(String deviceID) {
        return mDeviceRepository.getDeviceID(deviceID);
    }

    @Override
    public void setSensorStatus(String deviceID, boolean sensorStatus) {
        mDeviceRepository.setSensorStatus(deviceID, sensorStatus);
    }

    @Override
    public boolean getSensorStatus(String deviceID) {
        return mDeviceRepository.getSensorStatus(deviceID);
    }

    @Override
    public void setSensorType(String deviceID, String sensorType) {
        mDeviceRepository.setSensorType(deviceID, sensorType);
    }

    @Override
    public String getSensorType(String deviceID) {
        return mDeviceRepository.getSensorType(deviceID);
    }

    @Override
    public void setSensorMassage(String deviceID, int sensorMessage) {
        mDeviceRepository.setSensorMassage(deviceID, sensorMessage);
    }

    @Override
    public int getSensorMassage(String deviceID) {
        return mDeviceRepository.getSensorMassage(deviceID);
    }

    @Override
    public String getLocalDeviceUUID() {
        return mDeviceRepository.getLocalDeviceUUID();
    }

    @Override
    public String getSystemTimeStamp() {
        return null;
    }

    @Override
    public void startAlarmRecording() {
        mAlarmRecorder.startRecording();
    }

    @Override
    public void stopAlarmRecording(Context context) {
        mAlarmRecorder.stopRecording(context);
    }

    @Override
    public void setAlarmRecordingPreviewHolder(SurfaceHolder previewHolder) {
        mAlarmRecorder.setPreviewHolder(previewHolder);
    }
}
